==> tool-sql-1.1.10-sources.jar: io/ciera/tool/sql/ooaofooa/statemachine/impl/ActionHomeSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.statemachine.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.statemachine.ActionHome;
import io.ciera.tool.sql.ooaofooa.statemachine.ActionHomeSet;
import io.ciera.tool.sql.ooaofooa.statemachine.ActionSet;
import io.ciera.tool.sql.ooaofooa.statemachine.MealyActionHomeSet;
import io.ciera.tool.sql.ooaofooa.statemachine.MooreActionHomeSet;
import io.ciera.tool.sql.ooaofooa.statemachine.TransitionActionHomeSet;
import io.ciera.tool.sql.ooaofooa.statemachine.impl.ActionSetImpl;
import io.ciera.tool.sql.ooaofooa.statemachine.impl.MealyActionHomeSetImpl;
import io.ciera.tool.sql.ooaofooa.statemachine.impl.MooreActionHomeSetImpl;
import io.ciera.tool.sql.ooaofooa.statemachine.impl.TransitionActionHomeSetImpl;

import java.util.Arrays;
import java.util.List;


public class ActionHomeSetImpl extends InstanceSet<ActionHomeSet,ActionHome> implements ActionHomeSet {

    // attributes
    @Override
    public void setSM_ID( UniqueId ref_SM_ID ) throws XtumlException {
        for ( ActionHome actionhome : this ) actionhome.setSM_ID( ref_SM_ID );
    }
    @Override
    public void setAct_ID( UniqueId ref_Act_ID ) throws XtumlException {
        for ( ActionHome actionhome : this ) actionhome.setAct_ID( ref_Act_ID );
    }


    // selections
    @Override
    public MealyActionHomeSet R513_is_a_MealyActionHome() throws XtumlException {
        MealyActionHomeSet mealyactionhomeset = new MealyActionHomeSetImpl();
        for ( ActionHome actionhome : this ) mealyactionhomeset.add( actionhome.R513_is_a_MealyActionHome() );
        return mealyactionhomeset;
    }
    @Override
    public MooreActionHomeSet R513_is_a_MooreActionHome() throws XtumlException {
        MooreActionHomeSet mooreactionhomeset = new MooreActionHomeSetImpl();
        for ( ActionHome actionhome : this ) mooreactionhomeset.add( actionhome.R513_is_a_MooreActionHome() );
        return mooreactionhomeset;
    }
    @Override
    public TransitionActionHomeSet R513_is_a_TransitionActionHome() throws XtumlException {
        TransitionActionHomeSet transitionactionhomeset = new TransitionActionHomeSetImpl();
        for ( ActionHome actionhome : this ) transitionactionhomeset.add( actionhome.R513_is_a_TransitionActionHome() );
        return transitionactionhomeset;
    }
    @Override
    public ActionSet R514_houses_Action() throws XtumlException {
        ActionSet actionset = new ActionSetImpl();
        for ( ActionHome actionhome : this ) actionset.add( actionhome.R514_houses_Action() );
        return actionset;
    }


    @Override
    public ActionHome nullElement() {
        return ActionHomeImpl.EMPTY_ACTIONHOME;
    }

    @Override
    public ActionHomeSet emptySet() {
      return new ActionHomeSetImpl();
    }

    @Override
    public ActionHomeSet value() {
        return this;
    }

    @Override
    public List<ActionHome> elements() {
        return Arrays.asList(toArray(new ActionHome[0]));
    }

}

==> tool-sql-1.1.11-sources.jar: io/ciera/tool/sql/ooaofooa/statemachine/impl/ActionHomeSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.statemachine.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.statemachine.ActionHome;
import io.ciera.tool.sql.ooaofooa.statemachine.ActionHomeSet;
import io.ciera.tool.sql.ooaofooa.statemachine.ActionSet;
import io.ciera.tool.sql.ooaofooa.statemachine.MealyActionHomeSet;
import io.ciera.tool.sql.ooaofooa.statemachine.MooreActionHomeSet;
import io.ciera.tool.sql.ooaofooa.statemachine.TransitionActionHomeSet;
import io.ciera.tool.sql.ooaofooa.statemachine.impl.ActionSetImpl;
import io.ciera.tool.sql.ooaofooa.statemachine.impl.MealyActionHomeSetImpl;
import io.ciera.tool.sql.ooaofooa.statemachine.impl.MooreActionHomeSetImpl;
import io.ciera.tool.sql.ooaofooa.statemachine.impl.TransitionActionHomeSetImpl;

import java.util.Arrays;
import java.util.Comparator;
import java.util.List;


public class ActionHomeSetImpl extends InstanceSet<ActionHomeSet,ActionHome> implements ActionHomeSet {

    public ActionHomeSetImpl() {
    }

    public ActionHomeSetImpl(Comparator<? super ActionHome> comp) {
        super(comp);
    }

    // attributes
    @Override
    public void setAct_ID( UniqueId ref_Act_ID ) throws XtumlException {
        for ( ActionHome actionhome : this ) actionhome.setAct_ID( ref_Act_ID );
    }
    @Override
    public void setSM_ID( UniqueId ref_SM_ID ) throws XtumlException {
        for ( ActionHome actionhome : this ) actionhome.setSM_ID( ref_SM_ID );
    }


    // selections
    @Override
    public MealyActionHomeSet R513_is_a_MealyActionHome() throws XtumlException {
        MealyActionHomeSet mealyactionhomeset = new MealyActionHomeSetImpl();
        for ( ActionHome actionhome : this ) mealyactionhomeset.add( actionhome.R513_is_a_MealyActionHome() );
        return mealyactionhomeset;
    }
    @Override
    public MooreActionHomeSet R513_is_a_MooreActionHome() throws XtumlException {
        MooreActionHomeSet mooreactionhomeset = new MooreActionHomeSetImpl();
        for ( ActionHome actionhome : this ) mooreactionhomeset.add( actionhome.R513_is_a_MooreActionHome() );
        return mooreactionhomeset;
    }
    @Override
    public TransitionActionHomeSet R513_is_a_TransitionActionHome() throws XtumlException {
        TransitionActionHomeSet transitionactionhomeset = new TransitionActionHomeSetImpl();
        for ( ActionHome actionhome : this ) transitionactionhomeset.add( actionhome.R513_is_a_TransitionActionHome() );
        return transitionactionhomeset;
    }
    @Override
    public ActionSet R514_houses_Action() throws XtumlException {
        ActionSet actionset = new ActionSetImpl();
        for ( ActionHome actionhome : this ) actionset.add( actionhome.R514_houses_Action() );
        return actionset;
    }


    @Override
    public ActionHome nullElement() {
        return ActionHomeImpl.EMPTY_ACTIONHOME;
    }

    @Override
    public ActionHomeSet emptySet() {
      return new ActionHomeSetImpl();
    }

    @Override
    public ActionHomeSet emptySet(Comparator<? super ActionHome> comp) {
      return new ActionHomeSetImpl(comp);
    }

    @Override
    public ActionHomeSet value() {
        return this;
    }

    @Override
    public List<ActionHome> elements() {
        return Arrays.asList(toArray(new ActionHome[0]));
    }

}
